
The latest version is 2.1.0, released 2016-11-17.

.. raw:: html

	<a class="download downloadBox" href="https://github.com/schollz/gojot/releases/download/2.1.0/gojot-2.1.0-win64.zip">
	<div class="platform">Microsoft Windows</div>
	<div class="reqs">Windows XP or later, Intel 64-bit processor</div>
	<div>
	<span class="filename">gojot-2.1.0-win64.zip</span>
	<span class="size">(7 MB)</span>
	</div>
	<div class="checksum">SHA256: a4f71d82e38c1857cb45adc29041f55747468ef1734d9ef00468e36b60852db3</div>
	</a>


.. raw:: html

	<a class="download downloadBox" href="https://github.com/schollz/gojot/releases/download/2.1.0/gojot-2.1.0-osx.tar.gz">
	<div class="platform">Apple OS X</div>
	<div class="reqs">OS X 10.8 or later, Intel 64-bit processor</div>
	<div>
	<span class="filename">gojot-2.1.0-osx.tar.gz</span>
	<span class="size">(7 MB)</span>
	</div>
	<div class="checksum">SHA256: 7f5548aee2e1ac4727de09af98edc557824b8717fd9d1f73e3c71ad49eb48f90</div>
	</a>


.. raw:: html

	<a class="download downloadBox" href="https://github.com/schollz/gojot/releases/download/2.1.0/gojot-2.1.0-linux64.tar.gz">
	<div class="platform">Linux x64</div>
	<div class="reqs">Linux 2.6.23 or later, Intel 64-bit processor</div>
	<div>
	<span class="filename">gojot-2.1.0-linux64.tar.gz</span>
	<span class="size">(7 MB)</span>
	</div>
	<div class="checksum">SHA256: 871e57cdad9ef5749297f34cc0b913cc6b42d96441860467c081ed2229f044c7</div>
	</a>


.. raw:: html

	<a class="download downloadBox" href="https://github.com/schollz/gojot/releases/download/2.1.0/gojot-2.1.0-linux-arm.tar.gz">
	<div class="platform">Linux ARM / Raspberry Pi</div>
	<div class="reqs">Linux 2.6.23 or later, ARM processor</div>
	<div>
	<span class="filename">gojot-2.1.0-linux-arm.tar.gz</span>
	<span class="size">(6 MB)</span>
	</div>
	<div class="checksum">SHA256: 6a15d9f4f5b8d5796316eb6a0f81cb0844fb255d205baca917c0fe059ac28781</div>
	</a>


